==> holado-0.2.3.tar.gz: holado-0.2.3/src/holado_binary/tests/behave/steps/ipc/binary_steps.py <==
# -*- coding: utf-8 -*-

#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################


from holado_test.behave.behave import *
from holado_test.scenario.step_tools import StepTools
import logging
from holado_binary.ipc.binary import Binary
from holado.common.context.session_context import SessionContext

logger = logging.getLogger(__name__)



def __get_scenario_context():
    return SessionContext.instance().get_scenario_context()

def __get_text_interpreter():
    return __get_scenario_context().get_text_interpreter()

def __get_variable_manager():
    return __get_scenario_context().get_variable_manager()



@Step(r"(?P<var_name>{Variable}) = convert binary string (?P<bin_str>{Str}) to hexadecimal string")
def step_impl(context, var_name, bin_str):
    var_name = StepTools.evaluate_variable_name(var_name)
    bin_str = StepTools.evaluate_scenario_parameter(bin_str)
    
    res = Binary.convert_bin_str_to_hex_str(bin_str)
    
    __get_variable_manager().register_variable(var_name, res)

@Step(r"(?P<var_name>{Variable}) = convert hexadecimal string (?P<hex_str>{Str}) to binary string")
def step_impl(context, var_name, hex_str):
    var_name = StepTools.evaluate_variable_name(var_name)
    hex_str = StepTools.evaluate_scenario_parameter(hex_str)
    
    res = Binary.convert_hex_str_to_bin_str(hex_str)
    
    __get_variable_manager().register_variable(var_name, res)

==> holado-0.4.0.tar.gz: holado-0.4.0/src/holado_binary/tests/behave/steps/ipc/binary_steps.py <==
# -*- coding: utf-8 -*-

#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################


from holado_test.behave.behave import *  # @UnusedWildImport
from holado_test.scenario.step_tools import StepTools
import logging
from holado_binary.ipc.binary import Binary
from holado.common.context.session_context import SessionContext

logger = logging.getLogger(__name__)



def __get_scenario_context():
    return SessionContext.instance().get_scenario_context()

def __get_text_interpreter():
    return __get_scenario_context().get_text_interpreter()

def __get_variable_manager():
    return __get_scenario_context().get_variable_manager()



@Step(r"(?P<var_name>{Variable}) = convert binary string (?P<bin_str>{Str}) to hexadecimal string")
def step_impl(context, var_name, bin_str):
    var_name = StepTools.evaluate_variable_name(var_name)
    bin_str = StepTools.evaluate_scenario_parameter(bin_str)
    
    res = Binary.convert_bin_str_to_hex_str(bin_str)
    
    __get_variable_manager().register_variable(var_name, res)

@Step(r"(?P<var_name>{Variable}) = convert hexadecimal string (?P<hex_str>{Str}) to binary string")
def step_impl(context, var_name, hex_str):
    var_name = StepTools.evaluate_variable_name(var_name)
    hex_str = StepTools.evaluate_scenario_parameter(hex_str)
    
    res = Binary.convert_hex_str_to_bin_str(hex_str)
    
    __get_variable_manager().register_variable(var_name, res)
